@@ -13,6 +13,7 @@ from appium.webdriver.common.touch_action import TouchAction
 from time import sleep, time
 from robot import utils
 from base64 import b64decode
+from selenium.webdriver.remote.webelement import WebElement
 
 try:
     AppiumCommon = importlib.import_module('Helpers.AppiumCommon', package='Helpers')
@@ -1056,6 +1057,10 @@ class DesktopLibrary(AppiumLibrary):
             return desktop_session
 
     def _element_find(self, locator, first_only, *kwargs):
+        if isinstance(locator, WebElement):
+            if first_only:
+                return locator
+            return [locator]
         prefix, criteria = self._parse_locator(locator)
         driver = self._current_application()
         if prefix is None:
@@ -1126,7 +1131,7 @@ class DesktopLibrary(AppiumLibrary):
             locator_parts = locator.partition('=')
             if len(locator_parts[1]) > 0:
                 prefix = locator_parts[0].strip().lower()
-                criteria = locator_parts[2].strip()
+                criteria = locator_parts[2]
         return prefix, criteria
 
     def _wait_until_page_contains(self, text, timeout=None, error=None):
@@ -1161,3 +1166,7 @@ class DesktopLibrary(AppiumLibrary):
         if locator == self.current_element:
             return self.current_element
         return self._element_find(locator, True, True)
+
+    def _platform_dependant_press(self, actions, element, delay=1500):
+        """Decide press action based on platform"""
+        AppiumCommon._platform_dependant_press(self, actions, element, delay)
